"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.icalendar_event = exports.create_icalendar = exports.write_events_and_calendars_if_needed = void 0;
const fs_1 = require("../fs");
const helpers_1 = require("./helpers");
// import { parseICS, CalendarComponent } from 'ical';
const ical_generator_1 = require("ical-generator");
async function write_events_and_calendars_if_needed(state) {
    if (state.conf.events) {
        for (const entry of state.events) {
            const event = icalendar_event(state, entry);
            const cal_data = {
                prodId: {
                    company: 'jbrumond.me',
                    product: 'docs2website',
                    language: 'EN',
                },
                // ...
            };
            const calendar = create_icalendar(cal_data, event);
            const out_file = await (0, helpers_1.map_input_file_to_output_file)(state, entry.in_file, ['.html', '.md', '.markdown'], '.ics');
            await (0, fs_1.write_text)(out_file, calendar);
        }
        for (const series of state.event_series) {
            const events = series.entries.map((event) => {
                return icalendar_event(state, {
                    url: series.url,
                    in_file: series.in_file,
                    title: event.title || series.title,
                    description: series.description,
                    author_name: series.author_name,
                    author_email: series.author_email,
                    start: event.start,
                    end: event.end,
                    time_zone: event.time_zone,
                    location: event.location,
                });
            });
            const cal_data = {
                name: series.title,
                description: series.description,
                url: series.url,
                prodId: {
                    company: 'jbrumond.me',
                    product: 'docs2website',
                    language: 'EN',
                },
                // ...
            };
            const calendar = create_icalendar(cal_data, events);
            const out_file = await (0, helpers_1.map_input_file_to_output_file)(state, series.in_file, ['.html', '.md', '.markdown'], '.ics');
            await (0, fs_1.write_text)(out_file, calendar);
        }
    }
    if (state.conf.calendars) {
        for (let index = 0; index < state.conf.calendars.length; index++) {
            const cal_conf = state.conf.calendars[index];
            const cal_entries = state.calendars[index];
            for (const entry of cal_entries) {
                const event = icalendar_event(state, entry);
                const cal_data = {
                    name: cal_conf.title,
                    prodId: {
                        company: 'jbrumond.me',
                        product: 'docs2website',
                        language: 'EN',
                    },
                    // ...
                };
                const calendar = create_icalendar(cal_data, event);
                await (0, fs_1.write_text)(cal_conf.out_file, calendar);
            }
        }
    }
}
exports.write_events_and_calendars_if_needed = write_events_and_calendars_if_needed;
// export function parse_icalendar(contents: string) {
// 	const parsed = parseICS(contents);
// 	const calendar: CalendarComponent[] = [ ];
// 	for (const data of Object.values(parsed)) {
// 		calendar.push(data);
// 	}
// 	return calendar;
// }
function create_icalendar(cal, events) {
    const calendar = (0, ical_generator_1.default)(cal);
    if (Array.isArray(events)) {
        for (const event of events) {
            calendar.createEvent(event);
        }
    }
    else {
        calendar.createEvent(events);
    }
    return calendar.toString();
}
exports.create_icalendar = create_icalendar;
function icalendar_event(state, entry) {
    const in_file = entry.in_file.slice(state.conf.input.root.length);
    const metadata = state.new_metadata.files[in_file];
    return {
        id: entry.url,
        summary: entry.title,
        description: entry.description || void 0,
        start: entry.start,
        end: entry.end,
        url: entry.url,
        timezone: entry.time_zone,
        created: metadata.first_seen_time,
        lastModified: metadata.last_updated_time,
        organizer: {
            name: entry.author_name || 'Unknown',
            email: entry.author_email,
        },
        location: format_location(entry.location),
        // attendees: post.mentions.flatMap((mention) : ICalAttendeeData | ICalAttendeeData[] => {
        // 	if (mention.is_rsvp && mention.is_reply_to_this) {
        // 		const ext = mention.external as ExternalEntry;
        // 		const status = ext.rsvp_type === 'yes'
        // 			? 'ACCEPTED' as const
        // 			: ext.rsvp_type === 'no'
        // 				? 'DECLINED' as const
        // 				: ext.rsvp_type === 'maybe'
        // 					? 'TENTATIVE' as const
        // 					: 'NEEDS-ACTION' as const;
        // 		return {
        // 			name: mention.author_name,
        // 			rsvp: ext.rsvp_type === 'yes',
        // 			status: status as ICalAttendeeStatus
        // 		};
        // 	}
        // 	return [ ];
        // }),
    };
}
exports.icalendar_event = icalendar_event;
function format_location(loc) {
    if (!loc) {
        return;
    }
    if (loc.description) {
        if (loc.address) {
            return `${loc.description} (${loc.address})`;
        }
        if (loc.lat && loc.long) {
            return `${loc.description} [${loc.lat}, ${loc.long}]`;
        }
        return loc.description;
    }
    if (loc.address) {
        return loc.address;
    }
    if (loc.lat && loc.long) {
        return `[${loc.lat}, ${loc.long}]`;
    }
}
//# sourceMappingURL=icalendar.js.map