"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.render_json_schema = exports.handle_json_schema_yaml_file = exports.handle_json_schema_json_file = exports.render_json_schema_files = void 0;
const glob_1 = require("glob");
const fs_1 = require("../fs");
const jsonschema2markdown_1 = require("@doc-utils/jsonschema2markdown");
const yaml_1 = require("yaml");
const helpers_1 = require("./helpers");
async function render_json_schema_files(state) {
    const promises = [];
    const json_files = await (0, glob_1.glob)(state.conf.input['schema+json'], {
        absolute: true,
        cwd: state.conf.input.root,
    });
    const yaml_files = await (0, glob_1.glob)(state.conf.input['schema+yaml'], {
        absolute: true,
        cwd: state.conf.input.root,
    });
    if (!state.partials) {
        await (0, helpers_1.build_partials)(state);
    }
    for (const in_file of json_files) {
        if (state.seen_files.has(in_file)) {
            continue;
        }
        state.seen_files.add(in_file);
        promises.push(handle_json_schema_json_file(state, in_file));
    }
    for (const in_file of yaml_files) {
        if (state.seen_files.has(in_file)) {
            continue;
        }
        state.seen_files.add(in_file);
        promises.push(handle_json_schema_yaml_file(state, in_file));
    }
    await Promise.all(promises);
}
exports.render_json_schema_files = render_json_schema_files;
async function handle_json_schema_json_file(state, in_file) {
    const promises = [];
    const out_file = (0, helpers_1.map_input_file_to_output_file)(state, in_file, ['.json'], '.html');
    const { frontmatter, parsed, json, hash } = await (0, fs_1.read_json)(in_file, true);
    promises.push(render_json_schema(state, parsed, in_file, await out_file, hash, frontmatter));
    if (state.conf.output.include_inputs?.includes('schema+json')) {
        const json_file = await (0, helpers_1.map_input_file_to_output_file)(state, in_file);
        promises.push((0, fs_1.write_text)(json_file, json));
        if (state.conf.output.include_yaml_and_json) {
            const yaml_file = await (0, helpers_1.map_input_file_to_output_file)(state, in_file, ['.json'], '.yaml');
            promises.push((0, fs_1.write_text)(yaml_file, (0, yaml_1.stringify)(parsed)));
        }
    }
    await Promise.all(promises);
}
exports.handle_json_schema_json_file = handle_json_schema_json_file;
async function handle_json_schema_yaml_file(state, in_file) {
    const promises = [];
    const out_file = (0, helpers_1.map_input_file_to_output_file)(state, in_file, ['.yaml', '.yml'], '.html');
    const { frontmatter, parsed, yaml, hash } = await (0, fs_1.read_yaml)(in_file, true);
    promises.push(render_json_schema(state, parsed, in_file, await out_file, hash, frontmatter));
    if (state.conf.output.include_inputs?.includes('schema+yaml')) {
        const yaml_file = await (0, helpers_1.map_input_file_to_output_file)(state, in_file);
        promises.push((0, fs_1.write_text)(yaml_file, yaml));
        if (state.conf.output.include_yaml_and_json) {
            const json_file = await (0, helpers_1.map_input_file_to_output_file)(state, in_file, ['.yaml', '.yml'], '.json');
            promises.push((0, fs_1.write_text)(json_file, JSON.stringify(parsed, null, '  ')));
        }
    }
    await Promise.all(promises);
}
exports.handle_json_schema_yaml_file = handle_json_schema_yaml_file;
async function render_json_schema(state, schema, in_file, out_file, hash, frontmatter) {
    if (frontmatter?.skip) {
        return;
    }
    const out_url = (0, helpers_1.map_output_file_to_url)(state, out_file);
    const promises = [];
    const markdown = (0, jsonschema2markdown_1.build_markdown_from_json_schema)(schema);
    if (state.conf.output.include_intermediate_markdown) {
        promises.push((0, helpers_1.map_input_file_to_output_file)(state, out_file, ['.html'], '.md')
            .then((md_file) => (0, fs_1.write_text)(md_file, markdown)));
    }
    promises.push((0, helpers_1.render_page)(state, in_file, out_file, out_url, markdown, true, hash, frontmatter));
    await Promise.all(promises);
}
exports.render_json_schema = render_json_schema;
//# sourceMappingURL=jsonschema.js.map