"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.render_markdown_file = exports.render_markdown_files = void 0;
const glob_1 = require("glob");
const fs_1 = require("../fs");
const helpers_1 = require("./helpers");
async function render_markdown_files(state) {
    const promises = [];
    const files = await (0, glob_1.glob)(state.conf.input.markdown, {
        absolute: true,
        cwd: state.conf.input.root,
    });
    if (!state.partials) {
        await (0, helpers_1.build_partials)(state);
    }
    for (const in_file of files) {
        if (state.seen_files.has(in_file)) {
            continue;
        }
        state.seen_files.add(in_file);
        promises.push(render_markdown_file(state, in_file));
    }
    await Promise.all(promises);
}
exports.render_markdown_files = render_markdown_files;
async function render_markdown_file(state, in_file) {
    const out_file = await (0, helpers_1.map_input_file_to_output_file)(state, in_file, ['.md', '.markdown'], '.html');
    const out_url = (0, helpers_1.map_output_file_to_url)(state, out_file);
    const { frontmatter, text, hash } = await (0, fs_1.read_text)(in_file);
    if (frontmatter?.skip) {
        return;
    }
    await (0, helpers_1.render_page)(state, in_file, out_file, out_url, text, true, hash, frontmatter);
}
exports.render_markdown_file = render_markdown_file;
//# sourceMappingURL=markdown.js.map