"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.write_sitemap_if_needed = void 0;
const xmlbuilder2_1 = require("xmlbuilder2");
const fs_1 = require("../fs");
const path_1 = require("path");
async function write_sitemap_if_needed(state) {
    if (!state.conf.sitemap) {
        return;
    }
    const doc = (0, xmlbuilder2_1.create)({ version: '1.0', encoding: 'UTF-8' });
    const urlset = doc.ele('urlset', {
        'xmlns': 'http://www.sitemaps.org/schemas/sitemap/0.9',
        'xmlns:xsi': 'http://www.w3.org/2001/XMLSchema-instance',
        'xsi:schemaLocation': 'http://www.sitemaps.org/schemas/sitemap/0.9 http://www.sitemaps.org/schemas/sitemap/0.9/sitemap.xsd'
    });
    for (const entry of state.sitemap) {
        url_elem(urlset, entry.url, entry.lastmod, entry.change_freq, entry.priority);
    }
    const out_file = state.conf.sitemap.out_file || (0, path_1.resolve)(state.conf.output.root, 'sitemap.xml');
    const xml = doc.toString({
        indent: '  ',
        prettyPrint: true,
    });
    await (0, fs_1.write_text)(out_file, xml);
}
exports.write_sitemap_if_needed = write_sitemap_if_needed;
function url_elem(urlset, loc, lastmod, change_freq, priority) {
    const url = urlset.ele('url');
    url.ele('loc').txt(loc);
    url.ele('lastmod').txt(lastmod);
    if (change_freq) {
        url.ele('changefreq').txt(change_freq);
    }
    if (priority != null) {
        url.ele('priority').txt(priority.toFixed(1));
    }
    return url;
}
//# sourceMappingURL=sitemap.js.map