import { MarkdownOptions } from '@doc-utils/markdown2html';
export declare const app_version: any;
export declare function read_config(file: string): Promise<Config>;
export interface RSSConfig {
    in_dir: string;
    out_file: string;
    title?: string;
    description?: string;
    link?: string;
    xsl?: string[];
    language?: string;
    copyright?: string;
    alternates?: {
        type: string;
        href: string;
    }[];
}
export interface CalendarConfig {
    in_dir?: string;
    out_file?: string;
    title?: string;
}
export interface AuthorConfig {
    name?: string;
    email?: string;
    url?: string;
}
export interface Config {
    title: string;
    metadata: string;
    base_url: string;
    authors?: Record<string, AuthorConfig>;
    input: {
        root: string;
        raw?: string[];
        text?: string[];
        markdown?: string[];
        'schema+json'?: string[];
        'schema+yaml'?: string[];
        'openapi+json'?: string[];
        'openapi+yaml'?: string[];
    };
    templates?: {
        layouts?: string;
        partials?: string;
        themes?: string;
        tags?: [string, string];
        env?: string[];
    };
    output: {
        root: string;
        include_inputs?: string[];
        include_yaml_and_json?: boolean;
        include_intermediate_markdown?: boolean;
    };
    sitemap?: false | {
        out_file?: string;
    };
    rss?: false | RSSConfig[];
    events?: false | {};
    calendars?: false | CalendarConfig[];
    markdown?: Omit<MarkdownOptions, 'base_url' | 'inline' | 'extensions'>;
    schema?: {};
    openapi?: {};
}
