"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.read_config = exports.app_version = void 0;
const fs_1 = require("fs");
const yaml_1 = require("yaml");
const path_1 = require("path");
exports.app_version = require('../package.json').version;
async function read_config(file) {
    const path = (0, path_1.resolve)(process.cwd(), file);
    const yaml = await fs_1.promises.readFile(path, 'utf8');
    const config = (0, yaml_1.parse)(yaml);
    validate_config(config);
    config.title = resolve_env_var_if_needed(config.title);
    config.metadata = resolve_env_var_if_needed(config.metadata);
    config.base_url = resolve_env_var_if_needed(config.base_url);
    config.input.root = resolve_env_var_if_needed(config.input.root);
    config.output.root = resolve_env_var_if_needed(config.output.root);
    process_markdown_config(config);
    resolve_paths(path, config);
    return config;
}
exports.read_config = read_config;
function validate_config(config) {
    // todo: validate config
}
function resolve_paths(file_path, config) {
    const base_path = (0, path_1.dirname)(file_path);
    config.input.root = (0, path_1.resolve)(base_path, config.input.root);
    config.output.root = (0, path_1.resolve)(base_path, config.output.root);
    config.metadata = (0, path_1.resolve)(base_path, config.metadata);
    if (config.templates?.layouts) {
        config.templates.layouts = (0, path_1.resolve)(base_path, config.templates.layouts);
    }
    if (config.templates?.partials) {
        config.templates.partials = (0, path_1.resolve)(base_path, config.templates.partials);
    }
    if (config.sitemap === true) {
        config.sitemap = {};
    }
    if (config.events === true) {
        config.events = {};
    }
    if (Array.isArray(config.rss)) {
        for (const rss_conf of config.rss) {
            if (rss_conf.in_dir) {
                rss_conf.in_dir = (0, path_1.resolve)(config.input.root, rss_conf.in_dir);
                rss_conf.out_file = (0, path_1.resolve)(config.output.root, rss_conf.out_file);
            }
        }
    }
    if (config.sitemap && typeof config.sitemap === 'object' && config.sitemap.out_file) {
        config.sitemap.out_file = (0, path_1.resolve)(config.output.root, config.sitemap.out_file);
    }
    if (Array.isArray(config.calendars)) {
        for (const cal_conf of config.calendars) {
            if (cal_conf.in_dir) {
                cal_conf.in_dir = (0, path_1.resolve)(config.input.root, cal_conf.in_dir);
                cal_conf.out_file = (0, path_1.resolve)(config.output.root, cal_conf.out_file);
            }
        }
    }
}
function process_markdown_config(config) {
    if (config?.markdown?.custom_elements) {
        if (config.markdown.custom_elements.tag_names) {
            const tags = new Set(config.markdown.custom_elements.tag_names);
            config.markdown.custom_elements.tagNameCheck = (tag_name) => tags.has(tag_name);
            delete config.markdown.custom_elements.tag_names;
        }
        if (config.markdown.custom_elements.attribute_names) {
            const attrs = new Set(config.markdown.custom_elements.attribute_names);
            config.markdown.custom_elements.attributeNameCheck = (attr_name) => attrs.has(attr_name);
            delete config.markdown.custom_elements.attribute_names;
        }
    }
}
function resolve_env_var_if_needed(value) {
    if (typeof value === 'object' && 'from_env' in value) {
        return process.env[value.from_env];
    }
    return value;
}
//# sourceMappingURL=conf.js.map