import { AuthorConfig, CalendarConfig, Config, RSSConfig } from './conf';
import { ColorTheme } from '@doc-utils/color-themes';
import { ThemeGroups } from './build-files';
import { ChangeFreq } from './build-files/sitemap';
export interface Context {
    env?: Record<string, string>;
    page?: FrontMatter;
    base_url: string;
    page_url: string;
    page_published: ContextTime;
    page_updated: ContextTime;
    site_title: string;
    author: AuthorConfig | AuthorConfig[];
    event?: ContextEvent | ContextEvent[];
    event_series?: {
        start?: ContextTime;
        end?: ContextTime;
    };
    icons: Record<string, string>;
    themes: ColorTheme[];
    theme_groups: ThemeGroups;
    rss_feeds: RSSConfig[];
    calendars: CalendarConfig[];
    build_time: ContextTime;
    markdown: {
        render_inline(): MustacheRenderer;
    };
}
export interface ContextTime {
    iso: string;
    rfc2822: string;
    html: string;
}
export interface ContextEvent {
    title?: string;
    start?: ContextTime;
    end?: ContextTime;
    time_zone?: `${string}/${string}`;
    location?: ContextLocation;
}
export interface ContextLocation {
    description?: string;
    lat?: string;
    long?: string;
    address?: string;
}
export interface FrontMatter {
    skip?: boolean;
    layout?: string;
    title?: string;
    description?: string;
    tags?: string[];
    author?: string | string[];
    rss?: RSSFrontmatter;
    sitemap?: SitemapFrontmatter;
    event?: EventFrontmatter | EventFrontmatter[];
    [key: string]: unknown;
}
export interface SitemapFrontmatter {
    skip?: boolean;
    change_freq?: ChangeFreq;
    priority?: number;
}
export interface EventFrontmatter {
    title?: string;
    start?: string;
    end?: string;
    time_zone?: `${string}/${string}`;
    location?: FrontMatterLocation;
}
export interface FrontMatterLocation {
    description?: string;
    lat?: string;
    long?: string;
    address?: string;
}
export interface RSSFrontmatter {
    skip?: boolean;
}
export declare function render_template(template: string, context: Context, layout?: string, partials?: Record<string, string>, tags?: [string, string]): string;
export declare function load_extras(): Promise<Record<string, string>>;
export declare function load_layout(conf: Config, file: string): Promise<string>;
export declare function load_partials(conf: Config): Promise<Record<string, string>>;
export interface MustacheRenderer {
    (this: void, text: string, render: (text: string) => string): string;
}
